@@ -2,18 +2,18 @@ import click
 from .context_state import CliContextState
 
 
-def quite_mode_option(func):
+def quiet_mode_option(func):
     """
-    Add quite mode flag to context state
+    Add quiet mode flag to context state
 
     Args:
         func:
     """
     def callback(ctx, _, value):
         state = ctx.ensure_object(CliContextState)
-        state.quite_mode = value
+        state.quiet_mode = value
         return value
-    return click.option('-q', '--quite', default=False, is_flag=True, required=False, help='Run in quite mode.',
+    return click.option('-q', '--quiet', default=False, is_flag=True, required=False, help='Run in quiet mode.',
                         expose_value=False, callback=callback)(func)
 
 
@@ -24,5 +24,5 @@ def common_options(func):
     Args:
         func:
     """
-    func = quite_mode_option(func)
+    func = quiet_mode_option(func)
     return func
