@@ -6,12 +6,12 @@ class CliContextState:
     CLI Context State
     """
 
-    def __init__(self, quite_mode=False):
+    def __init__(self, quiet_mode=False):
         """
         Args:
-            quite_mode (bool): Run in quite mode
+            quiet_mode (bool): Run in quiet mode
         """
-        self.quite_mode = quite_mode
+        self.quiet_mode = quiet_mode
 
 
 pass_state = click.make_pass_decorator(CliContextState, ensure=True)  # pylint: disable=invalid-name
