@@ -327,6 +327,35 @@ def download_results(job_id, destination):
         error_message(f"Error occurred while getting job {job_id} results")
         exception_message(ex)
 
+@job_commands.command('tasks-list', context_settings=CONTEXT_SETTINGS, short_help="List all tasks of a job.")
+@click.argument('job_id', metavar='<JOB_ID>')
+def tasks_list(job_id):
+    """
+    List all tasks of a job.
+
+    $ disco job tasks-list <job_id>
+
+    You may use ‘job list’ command to get the job id.
+
+    Status description: \n
+
+    Created: The task is created\n\r
+    Failed: The task completed with failure\n\r
+    Queued: The task is queued\n\r
+    Running: The task is running\n\r
+    Stopped: The task is canceled\n\r
+    Success: The task completed successfully\n\r
+    """
+
+    if not verify_logged_in():
+        return
+    try:
+        job = Job(job_id)
+        tasks_list = job.get_tasks()
+        display_tasks_list(tasks_list)
+    except DiscoException as ex:
+        exception_message(ex)
+
 
 def display_job_list(job_list):
     """Receives a list of jobs and prints them as a table"""
@@ -337,6 +366,15 @@ def display_job_list(job_list):
     info_message(displayable_table)
 
 
+def display_tasks_list(tasks_list):
+    """Receives a list of tasks and prints them as a table"""
+    tabulated_array = []
+    for task in tasks_list:
+        tabulated_array.append([task.id, task.status, task.duration, task.input_file_id])
+    displayable_table = list_to_table(tabulated_array, ["ID", "Status", "Duration (ms)", "Data File ID"])
+    info_message(displayable_table)
+
+
 def display_job(job, job_status=None):
     """Displays the job id on the screen"""
     if job_status is None:
