@@ -10,6 +10,7 @@ DISCO_CONFIG_PATH = pathlib.Path.home() / '.disco_py'
 ENV_VAR_BASE_URL_NAME = 'DISCO_BASE_URL'
 ENV_VAR_EMAIL_NAME = 'DISCO_EMAIL'
 ENV_VAR_PASSWORD_NAME = 'DISCO_PASSWORD'
+ENV_VAR_DISABLE_PROGRESS_BAR = 'DISCO_DISABLE_PROGRESS_BAR'
 
 SECOND = 1
 MINUTE = 60 * SECOND
@@ -41,3 +42,12 @@ class TaskStatus(enum.Enum):
     success = 'Success'
     failed = 'Failed'
     deleted = 'Deleted'
+
+
+class ClusterType(enum.Enum):
+    """Cluster types"""
+    AWS = 'aws'
+    Azure = 'azure'
+    GCP = 'gcp'
+    Packet = 'packet'
+    OnPremise = 'onPremise'
