@@ -69,23 +69,7 @@ class Job(BaseController):
     @classmethod
     def _get_venv_requirements(cls, cluster_id: str):
         if is_venv():
-            freeze_command = [sys.executable, '-m', 'pip', 'freeze']
-
-            process = subprocess.Popen(
-                freeze_command,
-                stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-            stdout, _ = process.communicate()
-            requirements = stdout.decode("utf-8")
-            # filtering out disco packages
-            split_req = filter(lambda line: "disco" not in line and "iqoqo" not in line and "Iqoqo" not in line,
-                               requirements.splitlines())
-            requirements = "\n".join(split_req) + "\ndiscomp"
-            req_file_id = Asset().upload(
-                'requirements.txt',
-                requirements,
-                cluster_id,
-                show_progress_bar=False)
-            return req_file_id
+            return cls.upload_requirements_file(cluster_id)
 
         print("Warning: Python virtual environment was not detected. "
               "Dis.co will not be able to automatically "
@@ -93,6 +77,42 @@ class Job(BaseController):
               "Python virtual environment.")
         return None
 
+    @classmethod
+    def upload_requirements_file(cls, cluster_id):
+        """
+        Uploads requirements file
+        Args:
+            cluster_id: Id for cluster to upload to
+
+        Returns:
+            ID of rquirements file in the db
+        """
+        requirements = cls.generate_requirements()
+        req_file_id = Asset().upload(
+            'requirements.txt',
+            requirements,
+            cluster_id,
+            show_progress_bar=False)
+        return req_file_id
+
+    @classmethod
+    def generate_requirements(cls):
+        """
+        Generates a string of requirements for requirements file
+        Returns:
+            \n seperated list of requirements
+        """
+        freeze_command = [sys.executable, '-m', 'pip', 'freeze']
+        process = subprocess.Popen(
+            freeze_command,
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        stdout, _ = process.communicate()
+        requirements = stdout.decode("utf-8")
+        # filtering out disco packages
+        split_req = filter(lambda line: "disco" not in line and "iqoqo" not in line and "Iqoqo" not in line,
+                           requirements.splitlines())
+        return "\n".join(split_req)
+
     @classmethod
     def create(  # pylint: disable-msg=too-many-arguments,too-many-locals
             cls,
