@@ -11,7 +11,7 @@ from disco.core.constants import JobStatus, ClusterType
 from disco.task import TaskResult
 
 from .sdk_mocks import MockListJobsResponse, MockViewJobResponse, MockBadIdException, \
-    MockViewStoppedJobResponse
+    MockViewStoppedJobResponse, MockListTasksResponse
 from mock import patch, call
 from click.testing import CliRunner
 from disco_cli import cli, setup_cli
@@ -99,6 +99,21 @@ class TestJobCommands(BaseTest):
         assert output_message_includes(result, "success: 2")
         assert output_message_includes(result, "stopped: 2")
 
+    @patch('disco.gql.authentication.Authentication.is_logged_in')
+    def test_tasks_list(self, is_logged_in_mock):
+        """
+        Tests tasks list
+        """
+        is_logged_in_mock.return_value = True
+        with patch('disco.Job.get_tasks') as list_tasks_mock:
+            list_tasks_mock.return_value = MockListTasksResponse
+            runner = CliRunner()
+            result = runner.invoke(cli, ['job', 'tasks-list', 'job_id'])
+            assert result.exit_code == 0
+            list_tasks_mock.assert_called()
+            is_logged_in_mock.assert_called()
+            assert output_message_includes(result, '| 5e4bef1942abec000cab2a71 | Success  |           17602 | 5e4beee087b4b2000edc6f2e |')
+
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.create')
     @patch('pathlib.Path.exists')
