@@ -262,20 +262,6 @@ class TestJobs(BaseTest):
                                                  'scriptFilePath': file_path}, options={'executeOnSubmit': False})
             assert job.job_id == expected_job_id
 
-    @BaseTest.with_config_and_env(authenticated=True)
-    @mock.patch('disco.job.Job.get_details')
-    def test_job_status_failed_tasks(self, mock_get_details):
-        mock_get_details.return_value = JobDetails({
-            'status': 'Done',
-            'tasksSummary': {
-                'success': 7,
-                'failed': 1
-            }
-        })
-        job = disco.Job('job_id')
-        status = job.get_status()
-        assert str(status) == 'JobStatus.failed'
-
     @BaseTest.with_config_and_env(authenticated=True)
     @mock.patch('disco.job.Job._download_task_results')
     def test_job_get_results_no_block(self, mock_download_task_results):
